****** Make Friends with SAS Day 1 activity;

* Example data: moms and dads from 1000 families, 2 outcomes at 5 occasions;

******************************************************************************
* Task 1: Merge all mom and dad data together from 3 separate files.
  Note this will require 2 different kinds of merges in 2 steps.
  2 are SPSS data files (mom500 and mom1000), one is excel (dad1000).
  They contain information on mom and dad monitoring (mmon and dmon)
   of an adolescent from age 13 to 17.
  Make sure to sort by family ID first in each, 
   sand make sure the family ID variable is the same.
  Make sure to add labels to any variables that need them.
******************************************************************************;

* First define a placeholder and library for the SAS file we will be using;
	%LET activ1= F:\13_Psyc930SAS\Day1_Activity;
	LIBNAME activ1 "&activ1.";

* Import each mom SPSS file directly and sort by ID;
	PROC IMPORT DATAFILE = "&activ1.\mom500.sav" 
		OUT=work.mom500 DBMS=SAV REPLACE;  
	RUN;
	PROC SORT DATA=mom500;
		BY FamilyID;
	RUN;
	PROC IMPORT DATAFILE = "&activ1.\mom1000.sav" 
		OUT=work.mom1000 DBMS=SAV REPLACE;  
	RUN;
	PROC SORT DATA=mom1000;
		BY FamilyID;
	RUN;

/* OR -- Save each mom file as SAS file, then import into the work library and sort by ID;
	DATA work.mom500; 
		SET activ2.mom500;
	RUN;
	PROC SORT DATA=mom500;
		BY FamilyID;
	RUN;
	DATA work.mom1000; 
		SET activ2.mom1000;
	RUN;
	PROC SORT DATA=mom1000;
		BY FamilyID;
	RUN;
	*/

* Merge two SAS files together -- adding cases;
	DATA work.allmoms;
		MERGE work.mom500 work.mom1000;
		BY FamilyID;
	RUN;

* Import dad data from excel worksheet and sort by FamilyID;
	PROC IMPORT DATAFILE = "&activ1.\dad1000.xlsx" 
		OUT=work.dad1000 DBMS=XLSX REPLACE; 
		SHEET="DadData"; GETNAMES=YES; 
	RUN;
	PROC SORT DATA=dad1000;
		BY FamID;
	RUN;
* Add variable labels to dad file and rename IDvar for matching;
	DATA work.alldads;
		SET work.dad1000;
		RENAME FamID=FamilyID;
		LABEL 	dmon13= "dmon13: Dad Monitoring at Age 13"
				dmon14= "dmon14: Dad Monitoring at Age 14"
				dmon15= "dmon15: Dad Monitoring at Age 15"
				dmon16= "dmon16: Dad Monitoring at Age 16"
				dmon17= "dmon17: Dad Monitoring at Age 17";
	RUN;

* Merge mom and dad data together -- add variables;
	DATA work.momsdads;
		MERGE work.allmoms work.alldads;
		BY FamilyID;
	RUN;
	
******************************************************************************
* Task 2: Stack the combined mom and dad file.
  Use "Wave" as the new INDEX variable (from 1-5).
  Make sure to label all new stacked variables.
******************************************************************************;

* Stacking combined family multivariate file;
	DATA work.momsdadsstack; SET work.momsdads;
		wave=1; age=13; mmon=mmon13; dmon=dmon13; OUTPUT;
		wave=2; age=14; mmon=mmon14; dmon=dmon14; OUTPUT;
		wave=3; age=15; mmon=mmon15; dmon=dmon15; OUTPUT;
		wave=4; age=16; mmon=mmon16; dmon=dmon16; OUTPUT;
		wave=5; age=17; mmon=mmon17; dmon=dmon17; OUTPUT;
	LABEL	wave= 	"wave: Wave of Measurement (1-5)"
			age=	"age: Age of Measurement (13-17)"
			mmon=	"mmon: Mom Monitoring"
			dmon=	"dmon: Dad Monitoring";
	* Optional: drop old variables;
		DROP mmon13-mmon17 dmon13-dmon17;
	RUN;


******************************************************************************
* Task 3: In the "workhours" SAS data file:
  Import into the work library, and sort by family and wave.
  Save the mean and min "mwork" variable over waves per family to the dataset.
  Then merge the "workhours" file into other stacked mom/dad data.
  Save the final SAS dataset as "famstack".
******************************************************************************;

* Copy "workhours" file into "work" library;
	DATA work.workhours;
		SET activ1.workhours;
	RUN;
	PROC SORT DATA=work.workhours;
		BY FamilyID wave;
	RUN;

* Use PROC MEANS to get summary info;
	PROC SORT DATA=work.workhours; BY FamilyID; RUN;
	PROC MEANS NOPRINT DATA=work.workhours; 
		BY FamilyID;
		VAR mwork; 
		OUTPUT OUT=work.summary
			MEAN(mwork) = mworkMn
			MIN (mwork) = mworkMin;	 
	RUN;

* Merge summary variables back into workstack data, label new variables;
* Drop unnecessary variables created by PROC MEANS in summary data;
	DATA work.workhours;
		MERGE work.workhours work.summary;
		BY FamilyID;
		LABEL	mworkMn=  "mworkMn: Mean of Mwork over waves"
				mworkMin= "mworkMin: Min of Mwork over waves";
		DROP _TYPE_ _FREQ_;
	RUN;

* Merge back into momdad data;
	DATA work.famstack; 
		MERGE work.momsdadsstack work.workhours;
		BY FamilyID;
	RUN;

* Save finished data to permanent file;
	DATA activ1.famstack;
		SET work.famstack;
	RUN;



	

	   




